Package Name: matteplotlib

Command to install:
pip install matteplotlib

Use this Command to build:
python setup.py sdist bdist_wheel # To build

Use this Command to install locally for testing:
pip install .\dist\matplotib-0.4-py3-none-any.whl # To install locally(version vary according to build)

Use this command to upload to PyPi:
twine upload dist/*

API Token:
pypi-AgEIcHlwaS5vcmcCJDYyZGI3ZjA1LWIzNDEtNGMyZC1iOTFhLWE1ZGRhODRkN2ZlZAACKlszLCJkZjA1OTI4OC1iOTgzLTRhMjMtYTJmMS0xNTE1YjM5NjQ4MjIiXQAABiDLCXpzFN4FRDp-zwqL_FHx0z-TIMs1xnThReE_oWdanw

pypi-AgEIcHlwaS5vcmcCJDdkYzE1OTNiLThjMDItNDQzZS05NTkyLWNmODVkZmI1NWNhMAACFFsxLFsibWF0dGVwbG90bGliIl1dAAIsWzIsWyIxNjBmZjZkMS02Y2M2LTQzNTctOTZiYS1kYTM0MjFkNWI1ZGIiXV0AAAYgISXCdV3Ol_g1CyQfAm1gtaF7B-c84E9LPZAo6j0HPCw

pypi-AgEIcHlwaS5vcmcCJDFhYTQ5ZDc3LTk3ZDItNGE1MS1hOWY2LWQxNzgwMmZiYzNlMgACFFsxLFsibWF0dGVwbG90bGliIl1dAAIsWzIsWyIxNjBmZjZkMS02Y2M2LTQzNTctOTZiYS1kYTM0MjFkNWI1ZGIiXV0AAAYgi3J71gt0gmcK3Gj20q1zDIoftWFA349AFhPN557vTws

pypi-AgEIcHlwaS5vcmcCJDMyNmY3NjE5LTlhNjMtNDAyMi1hYmUwLTI0OTE4ODk2MDFjMwACFFsxLFsibWF0dGVwbG90bGliIl1dAAIsWzIsWyIxNjBmZjZkMS02Y2M2LTQzNTctOTZiYS1kYTM0MjFkNWI1ZGIiXV0AAAYg8f-3kSYFBC6nWkJ9xt18EoJih_gts8vf5sQUFzHZ8eY

pypi-AgEIcHlwaS5vcmcCJGNiMmFmMzVhLTkzZTYtNGFmYi1iODliLWQ0MzI4YzMzNDBjYgACKlszLCJkZjA1OTI4OC1iOTgzLTRhMjMtYTJmMS0xNTE1YjM5NjQ4MjIiXQAABiCNAcGNYlDR5e1cOodN4Fc0DQO-99hFIejAok1zQA9Zrg